@@ -1,7 +1,4 @@
-try:
-    from importlib.metadata import version
-except ImportError:
-    from importlib_metadata import version  # type: ignore
+from importlib.metadata import version
 
 from schwifty.bban import BBAN
 from schwifty.bic import BIC
